pub struct ArchiveNavigator {
pub entries: Vec<ArchiveEntry>,
pub manifest: FxarManifest,
pub selected: usize,
}Expand description
Builds and navigates a virtual directory tree from a flat FXAR manifest.
Fields
entries: Vec<ArchiveEntry>Flat array of all nodes (root at index 0, then others).
manifest: FxarManifestselected: usizeSelected node index (for TUI cursor).
Implementations
Sourcepub fn from_manifest(manifest: FxarManifest) -> Result<Self>
pub fn from_manifest(manifest: FxarManifest) -> Result<Self>
Open the manifest and build the virtual tree.
pub fn root(&self) -> &ArchiveEntry
pub fn entry_at(&self, idx: usize) -> Option<&ArchiveEntry>
pub fn children_of(&self, idx: usize) -> &[usize]
pub fn parent_of(&self, idx: usize) -> Option<usize>
pub fn manifest_entry_for(&self, idx: usize) -> Option<&FxarManifestEntry>
pub fn select_next(&mut self)
pub fn select_prev(&mut self)
pub fn selected_entry(&self) -> Option<&ArchiveEntry>
Sourcepub fn list_snapshots(&self) -> &[String]
pub fn list_snapshots(&self) -> &[String]
Returns the list of snapshot names from the manifest.
Sourcepub fn snapshot_entry_count(&self, snapshot: &str) -> usize
pub fn snapshot_entry_count(&self, snapshot: &str) -> usize
Count entries (files and dirs) whose path starts with snapshot/ or equals snapshot.